@@ -102,7 +102,7 @@ _GETEVENTSUNTIL_REQ    = _BASE_URL + "api/geteventsuntil"
 
 #TODO# Undocumented (but would be very usefull) API : Access currently forbidden (403)
 
-# _POST_UPDATE_HOME_REQ  = _BASE_URL + "/api/updatehome"
+_POST_UPDATE_HOME_REQ  = _BASE_URL + "/api/updatehome"
 
 # For presence setting (POST BODY):
 # _PRES_BODY_REC_SET     = "home_id=%s&presence_settings[presence_record_%s]=%s"   # (HomeId, DetectionKind, DetectionSetup.index)
@@ -275,7 +275,7 @@ class ThermostatData:
         resp = postRequest(_GETTHERMOSTATDATA_REQ, postParams)
         self.rawData = resp['body']['devices']
         if not self.rawData : raise NoDevice("No thermostat available")
-        self.thermostatData = filter_home_data(rawData, home)
+        self.thermostatData = filter_home_data(self.rawData, home)
         if not self.thermostatData : raise NoHome("No home %s found" % home)
         self.thermostatData['name'] = self.thermostatData['home_name']
         for m in self.thermostatData['modules']:
@@ -320,10 +320,10 @@ class WeatherStationData:
         self.stations = { d['station_name'] : d for d in self.rawData }
         self.homes = { d['home_name'] : d["station_name"] for d in self.rawData }
         # Keeping the old behavior for default station name
-        if station and station not in self.stations: raise NoDevice("No station with name %s" % station)
-        self.default_station = station or list(self.stations.keys())[0]
         if home and home not in self.homes : raise NoHome("No home with name %s" % home)
         self.default_home = home or list(self.homes.keys())[0]
+        if station and station not in self.stations: raise NoDevice("No station with name %s" % station)
+        self.default_station = station or [v["station_name"] for k,v in self.stations.items() if v["home_name"] == self.default_home][0]
         self.modules = dict()
         self.default_station_data = self.stationByName(self.default_station)
         if 'modules' in self.default_station_data:
@@ -392,15 +392,15 @@ class WeatherStationData:
                         if i in module : lastD[module['module_name']][i] = module[i]
         return lastD
 
-    def checkNotUpdated(self, station=None, delay=3600):
-        res = self.lastData(station)
+    def checkNotUpdated(self, delay=3600):
+        res = self.lastData()
         ret = []
         for mn,v in res.items():
             if time.time()-v['When'] > delay : ret.append(mn)
         return ret if ret else None
 
-    def checkUpdated(self, station=None, delay=3600):
-        res = self.lastData(station)
+    def checkUpdated(self, delay=3600):
+        res = self.lastData()
         ret = []
         for mn,v in res.items():
             if time.time()-v['When'] < delay : ret.append(mn)
@@ -824,7 +824,7 @@ def getStationMinMaxTH(station=None, module=None, home=None):
             r = devList.MinMaxTH(module=m)
             result[m] = (r[0], lastD[m]['Temperature'], r[1])
     else:
-        if time.time()-lastD[mname]['When'] > 3600 : result = ["-", "-"]
+        if time.time()-lastD[module]['When'] > 3600 : result = ["-", "-"]
         else : 
             result = [lastD[module]['Temperature'], lastD[module]['Humidity']]
             result.extend(devList.MinMaxTH(module))
